# Table of Contents

- [application-modernization-transformations-and-roadmap](<./application-modernization-transformations-and-roadmap.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 5: Plan Transformations and Create a Roadmap](<./Step-5-Plan-Transformations-and-Create-a-Roadmap.md>)
  - [Create and Structure Your Initiatives](<./Step-5-Plan-Transformations-and-Create-a-Roadmap/Create-and-Structure-Your-Initiatives.md>)
  - [Add Key Milestones and Set the Lifecycle](<./Step-5-Plan-Transformations-and-Create-a-Roadmap/Add-Key-Milestones-and-Set-the-Lifecycle.md>)
  - [Create Transformations](<./Step-5-Plan-Transformations-and-Create-a-Roadmap/Create-Transformations.md>)
  - [Create a Roadmap](<./Step-5-Plan-Transformations-and-Create-a-Roadmap/Create-a-Roadmap.md>)
